# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import appointment_template_line_pb2 as v1_dot_rules_dot_appointment__template__line__pb2


class AppointmentTemplateLineServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AppointmentTemplateLineCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineService/AppointmentTemplateLineCreate",
            request_serializer=v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineCreateResponse.FromString,
        )
        self.AppointmentTemplateLineRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineService/AppointmentTemplateLineRead",
            request_serializer=v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineReadResponse.FromString,
        )
        self.AppointmentTemplateLineUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineService/AppointmentTemplateLineUpdate",
            request_serializer=v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineUpdateResponse.FromString,
        )
        self.AppointmentTemplateLineDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineService/AppointmentTemplateLineDelete",
            request_serializer=v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineDeleteResponse.FromString,
        )


class AppointmentTemplateLineServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AppointmentTemplateLineCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AppointmentTemplateLineRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AppointmentTemplateLineUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AppointmentTemplateLineDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_AppointmentTemplateLineServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "AppointmentTemplateLineCreate": grpc.unary_unary_rpc_method_handler(
            servicer.AppointmentTemplateLineCreate,
            request_deserializer=v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineCreateResponse.SerializeToString,
        ),
        "AppointmentTemplateLineRead": grpc.unary_unary_rpc_method_handler(
            servicer.AppointmentTemplateLineRead,
            request_deserializer=v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineReadResponse.SerializeToString,
        ),
        "AppointmentTemplateLineUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.AppointmentTemplateLineUpdate,
            request_deserializer=v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineUpdateResponse.SerializeToString,
        ),
        "AppointmentTemplateLineDelete": grpc.unary_unary_rpc_method_handler(
            servicer.AppointmentTemplateLineDelete,
            request_deserializer=v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class AppointmentTemplateLineService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AppointmentTemplateLineCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineService/AppointmentTemplateLineCreate",
            v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineCreateRequest.SerializeToString,
            v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AppointmentTemplateLineRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineService/AppointmentTemplateLineRead",
            v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineReadRequest.SerializeToString,
            v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AppointmentTemplateLineUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineService/AppointmentTemplateLineUpdate",
            v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineUpdateRequest.SerializeToString,
            v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AppointmentTemplateLineDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineService/AppointmentTemplateLineDelete",
            v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineDeleteRequest.SerializeToString,
            v1_dot_rules_dot_appointment__template__line__pb2.AppointmentTemplateLineDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
