# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/appointment_line.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fv1/rules/appointment_line.proto\x12*pro.omni.oms.api.v1.rules.appointment_line\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\x89\x02\n\x0f\x41ppointmentLine\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nhour_start\x18\x02 \x01(\t\x12\x10\n\x08hour_end\x18\x03 \x01(\t\x12\x15\n\rorder_numbers\x18\x04 \x01(\x05\x12\x1d\n\x15\x61ppointment_available\x18\x05 \x01(\x05\x12\x0c\n\x04\x63ids\x18\x06 \x03(\t\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x08 \x01(\t\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xd5\x01\n\x1c\x41ppointmentLineCreateRequest\x12\x12\n\nhour_start\x18\x01 \x01(\t\x12\x10\n\x08hour_end\x18\x02 \x01(\t\x12\x15\n\rorder_numbers\x18\x03 \x01(\x05\x12\x1d\n\x15\x61ppointment_available\x18\x04 \x01(\x05\x12\x0c\n\x04\x63ids\x18\x05 \x03(\t\x12\x13\n\x0b\x65xternal_id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc1\x01\n\x1d\x41ppointmentLineCreateResponse\x12U\n\x10\x61ppointment_line\x18\x01 \x01(\x0b\x32;.pro.omni.oms.api.v1.rules.appointment_line.AppointmentLine\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf8\x02\n\x1a\x41ppointmentLineReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xfb\x01\n\x1b\x41ppointmentLineReadResponse\x12V\n\x11\x61ppointment_lines\x18\x01 \x03(\x0b\x32;.pro.omni.oms.api.v1.rules.appointment_line.AppointmentLine\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xad\x01\n\x1c\x41ppointmentLineUpdateRequest\x12U\n\x10\x61ppointment_line\x18\x01 \x01(\x0b\x32;.pro.omni.oms.api.v1.rules.appointment_line.AppointmentLine\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc1\x01\n\x1d\x41ppointmentLineUpdateResponse\x12U\n\x10\x61ppointment_line\x18\x01 \x01(\x0b\x32;.pro.omni.oms.api.v1.rules.appointment_line.AppointmentLine\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"b\n\x1c\x41ppointmentLineDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"j\n\x1d\x41ppointmentLineDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xd6\x05\n\x16\x41ppointmentLineService\x12\xae\x01\n\x15\x41ppointmentLineCreate\x12H.pro.omni.oms.api.v1.rules.appointment_line.AppointmentLineCreateRequest\x1aI.pro.omni.oms.api.v1.rules.appointment_line.AppointmentLineCreateResponse"\x00\x12\xa8\x01\n\x13\x41ppointmentLineRead\x12\x46.pro.omni.oms.api.v1.rules.appointment_line.AppointmentLineReadRequest\x1aG.pro.omni.oms.api.v1.rules.appointment_line.AppointmentLineReadResponse"\x00\x12\xae\x01\n\x15\x41ppointmentLineUpdate\x12H.pro.omni.oms.api.v1.rules.appointment_line.AppointmentLineUpdateRequest\x1aI.pro.omni.oms.api.v1.rules.appointment_line.AppointmentLineUpdateResponse"\x00\x12\xae\x01\n\x15\x41ppointmentLineDelete\x12H.pro.omni.oms.api.v1.rules.appointment_line.AppointmentLineDeleteRequest\x1aI.pro.omni.oms.api.v1.rules.appointment_line.AppointmentLineDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.appointment_line_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    _globals["_APPOINTMENTLINE"]._serialized_start = 131
    _globals["_APPOINTMENTLINE"]._serialized_end = 396
    _globals["_APPOINTMENTLINECREATEREQUEST"]._serialized_start = 399
    _globals["_APPOINTMENTLINECREATEREQUEST"]._serialized_end = 612
    _globals["_APPOINTMENTLINECREATERESPONSE"]._serialized_start = 615
    _globals["_APPOINTMENTLINECREATERESPONSE"]._serialized_end = 808
    _globals["_APPOINTMENTLINEREADREQUEST"]._serialized_start = 811
    _globals["_APPOINTMENTLINEREADREQUEST"]._serialized_end = 1187
    _globals["_APPOINTMENTLINEREADRESPONSE"]._serialized_start = 1190
    _globals["_APPOINTMENTLINEREADRESPONSE"]._serialized_end = 1441
    _globals["_APPOINTMENTLINEUPDATEREQUEST"]._serialized_start = 1444
    _globals["_APPOINTMENTLINEUPDATEREQUEST"]._serialized_end = 1617
    _globals["_APPOINTMENTLINEUPDATERESPONSE"]._serialized_start = 1620
    _globals["_APPOINTMENTLINEUPDATERESPONSE"]._serialized_end = 1813
    _globals["_APPOINTMENTLINEDELETEREQUEST"]._serialized_start = 1815
    _globals["_APPOINTMENTLINEDELETEREQUEST"]._serialized_end = 1913
    _globals["_APPOINTMENTLINEDELETERESPONSE"]._serialized_start = 1915
    _globals["_APPOINTMENTLINEDELETERESPONSE"]._serialized_end = 2021
    _globals["_APPOINTMENTLINESERVICE"]._serialized_start = 2024
    _globals["_APPOINTMENTLINESERVICE"]._serialized_end = 2750
# @@protoc_insertion_point(module_scope)
