# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/appointment_template_line.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(v1/rules/appointment_template_line.proto\x12\x33pro.omni.oms.api.v1.rules.appointment_template_line\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xf1\x01\n\x17\x41ppointmentTemplateLine\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03\x64\x61y\x18\x02 \x01(\t\x12\x12\n\nhour_start\x18\x03 \x01(\t\x12\x10\n\x08hour_end\x18\x04 \x01(\t\x12\x15\n\rorder_numbers\x18\x05 \x01(\x05\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x08 \x01(\t\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xbd\x01\n$AppointmentTemplateLineCreateRequest\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\t\x12\x12\n\nhour_start\x18\x02 \x01(\t\x12\x10\n\x08hour_end\x18\x03 \x01(\t\x12\x15\n\rorder_numbers\x18\x04 \x01(\x05\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe3\x01\n%AppointmentTemplateLineCreateResponse\x12o\n\x19\x61ppointment_template_line\x18\x01 \x01(\x0b\x32L.pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLine\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x80\x03\n"AppointmentTemplateLineReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9d\x02\n#AppointmentTemplateLineReadResponse\x12p\n\x1a\x61ppointment_template_lines\x18\x01 \x03(\x0b\x32L.pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLine\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xcf\x01\n$AppointmentTemplateLineUpdateRequest\x12o\n\x19\x61ppointment_template_line\x18\x01 \x01(\x0b\x32L.pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLine\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe3\x01\n%AppointmentTemplateLineUpdateResponse\x12o\n\x19\x61ppointment_template_line\x18\x01 \x01(\x0b\x32L.pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLine\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"j\n$AppointmentTemplateLineDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"r\n%AppointmentTemplateLineDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x86\x07\n\x1e\x41ppointmentTemplateLineService\x12\xd8\x01\n\x1d\x41ppointmentTemplateLineCreate\x12Y.pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineCreateRequest\x1aZ.pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineCreateResponse"\x00\x12\xd2\x01\n\x1b\x41ppointmentTemplateLineRead\x12W.pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineReadRequest\x1aX.pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineReadResponse"\x00\x12\xd8\x01\n\x1d\x41ppointmentTemplateLineUpdate\x12Y.pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineUpdateRequest\x1aZ.pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineUpdateResponse"\x00\x12\xd8\x01\n\x1d\x41ppointmentTemplateLineDelete\x12Y.pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineDeleteRequest\x1aZ.pro.omni.oms.api.v1.rules.appointment_template_line.AppointmentTemplateLineDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.appointment_template_line_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    _globals["_APPOINTMENTTEMPLATELINE"]._serialized_start = 149
    _globals["_APPOINTMENTTEMPLATELINE"]._serialized_end = 390
    _globals["_APPOINTMENTTEMPLATELINECREATEREQUEST"]._serialized_start = 393
    _globals["_APPOINTMENTTEMPLATELINECREATEREQUEST"]._serialized_end = 582
    _globals["_APPOINTMENTTEMPLATELINECREATERESPONSE"]._serialized_start = 585
    _globals["_APPOINTMENTTEMPLATELINECREATERESPONSE"]._serialized_end = 812
    _globals["_APPOINTMENTTEMPLATELINEREADREQUEST"]._serialized_start = 815
    _globals["_APPOINTMENTTEMPLATELINEREADREQUEST"]._serialized_end = 1199
    _globals["_APPOINTMENTTEMPLATELINEREADRESPONSE"]._serialized_start = 1202
    _globals["_APPOINTMENTTEMPLATELINEREADRESPONSE"]._serialized_end = 1487
    _globals["_APPOINTMENTTEMPLATELINEUPDATEREQUEST"]._serialized_start = 1490
    _globals["_APPOINTMENTTEMPLATELINEUPDATEREQUEST"]._serialized_end = 1697
    _globals["_APPOINTMENTTEMPLATELINEUPDATERESPONSE"]._serialized_start = 1700
    _globals["_APPOINTMENTTEMPLATELINEUPDATERESPONSE"]._serialized_end = 1927
    _globals["_APPOINTMENTTEMPLATELINEDELETEREQUEST"]._serialized_start = 1929
    _globals["_APPOINTMENTTEMPLATELINEDELETEREQUEST"]._serialized_end = 2035
    _globals["_APPOINTMENTTEMPLATELINEDELETERESPONSE"]._serialized_start = 2037
    _globals["_APPOINTMENTTEMPLATELINEDELETERESPONSE"]._serialized_end = 2151
    _globals["_APPOINTMENTTEMPLATELINESERVICE"]._serialized_start = 2154
    _globals["_APPOINTMENTTEMPLATELINESERVICE"]._serialized_end = 3056
# @@protoc_insertion_point(module_scope)
